@@ -1513,7 +1513,7 @@ def device_list():
                 wavefront = api.DeviceParameters(device).warp_size
                 devices_list += (('cuda',  api_n, dev_num, platform, device, thr, wavefront),)
     except:
-        pass
+        print('No cuda device found. Check your pycuda installation.')
     try:
         api = cluda.ocl_api()
         available_ocl_device = cluda.find_devices(api)
@@ -1534,7 +1534,7 @@ def device_list():
                 wavefront = api.DeviceParameters(device).warp_size
                 devices_list += (('ocl',  api_n, dev_num, platform, device, thr, wavefront),)
     except:
-        pass    
+        print('No OpenCL device found. Check your pyopencl installation.')
 #             print("API='cuda',  ", "platform_number=", api_n,
 #                   ", device_number=", available_cuda_device[api_n][0])
 #     except:
@@ -1584,4 +1584,4 @@ def diagnose(verbosity=0):
 if __name__ == '__main__':
     devices = device_list()
     for pp in range(0, len(devices)):
-        print(devices[pp])
\ No newline at end of file
+        print(devices[pp])
